@@ -124,12 +124,30 @@ return undef;
 #
 # 0.014	27-Jun-2003	T. R. Wyant
 #		Released.
+#
+# 0.014_01 25-Jul-2003	T. R. Wyant
+#		Added hash argument assert_debug_priv to 'new' method.
+#			It's ignored, though, since this variant
+#			always asserts debug.
+#
+# 1.000 09-Oct-2003	T. R. Wyant
+#		When the only thing you've fixed in the last two months
+#			is the docs, it's time to call it production
+#			code. And if _that_ statement doesn't flush
+#			out more problems, nothing will.
+#
+# 1.005 15-Mar-2005	T. R. Wyant
+#		Move assertion of seDebugPriv to the point where we
+#		discover we can require Win32API::Registry, since we
+#		don't need to do it but once for the process (not once
+#		per instantiation of the object), and we don't leak
+#		token handles this way.
 
 package Win32::Process::Info::NT;
 
 use base qw{Win32::Process::Info};
 use vars qw{$VERSION};
-$VERSION = 0.014;
+$VERSION = 1.005;
 
 use vars qw {
     $AdjustTokenPrivileges
@@ -155,7 +173,6 @@ use vars qw {
     };
 use Carp;
 use File::Basename;
-use Time::Local;
 use Win32;
 use Win32::API;
 
@@ -187,7 +204,7 @@ return Win32::API->new (@_) ||
     Win32::Process::Info::DummyRoutine->new ();
 }
 
-my %lglarg = map {($_, 1)} qw{variant};
+my %lglarg = map {($_, 1)} qw{assert_debug_priv variant};
 
 sub new {
 my $class = shift;
@@ -210,7 +227,8 @@ $self->{_xfrm} = \%_transform;
 bless $self, $class;
 # We want to fail silently, since that's probably better than nothing.
 ##0.013	AllowPriv (SE_DEBUG_NAME, 1)
-$setpriv->();	##0.013
+$setpriv->() if $setpriv;	##0.013 ##1.005
+$setpriv = undef;		##1.005
 ##    or croak "Error - Failed to (try to) assert privilege @{[
 ##	SE_DEBUG_NAME]}; $^E"
     ;
@@ -741,7 +759,7 @@ NT 4.0 without WMI.
 
 =head1 AUTHOR
 
-Thomas R. Wyant, III (F<Thomas.R.Wyant-III@usa.dupont.com>)
+Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT
 
